@@ -40,13 +40,13 @@ identifier = Word(alphas,alphanums+'_')
 integer = Word(nums)
 enumValue = Group(identifier('name') + Optional(EQ + integer('value')))
 enumList = Group(enumValue + ZeroOrMore(COMMA + enumValue))
-enum = _enum + identifier('enum') + LBRACE + enumList('list') + RBRACE
+enum = _enum + identifier('enum') + LBRACE + enumList('names') + RBRACE
 
 # find instances of enums ignoring other syntax
 for item,start,stop in enum.scanString(sample):
     id = 0
-    for entry in item.list:
+    for entry in item.names:
         if entry.value != '':
             id = int(entry.value)
-        print '%s_%s = %d' % (item.enum.upper(),entry.name.upper(),id)
+        print('%s_%s = %d' % (item.enum.upper(),entry.name.upper(),id))
         id += 1
